package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=5F9B0DA5-3B4E-416C-BD75-2F0A790BA907</H3></P>
 *
 * Utility class, replaces any occurrence of "byte[]" in COM code
 *
 * @version CLSID=5F9B0DA5-3B4E-416C-BD75-2F0A790BA907 - 1.00
 * @com.register ( clsid=5F9B0DA5-3B4E-416C-BD75-2F0A790BA907, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class ByteArray
   implements com.ms.com.IUnknown
{
   byte[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return byte[] the internal array this class is wrapping
    */
   public byte[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(byte[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns byte at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public byte getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, byte value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return Byte.toString(array[index]);
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = Byte.parseByte(value);
   }

   /**
    * Sets the size of the byte[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      byte[] tmp = array;
      array = new byte[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the byte[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the byte[] to a hex encoded string
    * @return byte[] as a hex encoded string
    */
   public String toString()
   {
      byte[] barr = new byte[array.length*2];
      int ch;

      for (int i = 0; i < array.length; i++)
      {
        ch = (array[i] >> 4) & 0x0F;
        ch += ((ch > 9) ? 'A'-10 : '0');
        barr[i*2] = (byte)ch;
        ch = array[i] & 0x0F;
        ch += ((ch > 9) ? 'A'-10 : '0');
        barr[i*2+1] = (byte)ch;
      }

      return new String(barr);
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof ByteArray)
         this.array = ((ByteArray)buildObj).array;
      else
         this.array = (byte[])((byte[])buildObj).clone();
   }

   ByteArray setupObject(Object o)
   {
      this.array = (byte[])o;
      return this;
   }
}
