// COM proxy class, output from FunctionList.js
package owapi;
/**
 * CRC8 is a class to contain an implementation of the
 * Cyclic-Redundency-Check CRC8 for the iButton.  The CRC8 is used
 * in the 1-Wire Network address of all iButtons and 1-Wire
 * devices.
 * <p>
 * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
 *
 * @version CLSID=D45BA87F-AC46-4CC1-8723-BDA9906BBBEC -     0.00, 28 Aug 2000
 * @author     DS
 *
 * @com.register ( clsid=D45BA87F-AC46-4CC1-8723-BDA9906BBBEC, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class CRC8
   implements com.ms.com.IUnknown
{


   /**
    * Perform the CRC8 on the data element based on the provided seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   data element on which to perform the CRC8
    * @param   seed        seed the CRC8 with this value
    * @return  CRC8 value
    */
   public int compute(int dataToCRC, int seed)
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCRC, seed);
   }

   /**
    * Perform the CRC8 on the data element based on the provided seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   data element on which to perform the CRC8
    * @param   seed        seed the CRC8 with this value
    * @return  CRC8 value
    */
   public int compute(int dataToCRC)
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCRC);
   }

   /**
    * Perform the CRC8 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC8
    * @return  CRC8 value
    */
   public int computeFromBytes(ByteArray dataToCrc )
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCrc .array);
   }

   /**
    * Perform the CRC8 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC8
    * @param   off         offset into array
    * @param   len         length of data to crc
    * @return  CRC8 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off, int len)
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCrc .array, off, len);
   }

   /**
    * Perform the CRC8 on an array of data elements based on the
    * provided seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC8
    * @param   off         offset into array
    * @param   len         length of data to crc
    * @param   seed        seed to use for CRC8
    * @return  CRC8 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off, int len, int seed)
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCrc .array, off, len, seed);
   }

   /**
    * Perform the CRC8 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC8 is based on the polynomial = X^8 + X^5 + X^4 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC8
    * @param   off         offset into array
    * @param   len         length of data to crc
    * @return  CRC8 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off)
   {      
      return com.dalsemi.onewire.utils.CRC8.compute(dataToCrc .array, off);
   }


}
