// COM proxy class, output from FunctionList.js
package owapi;
/**
 * The abstract base class for all 1-Wire port
 * adapter objects.  An implementation class of this type is therefore
 * independent of the adapter type.  Instances of valid DSPortAdapter's are
 * retrieved from methods in
 * {@link 
 *
 * <P>The DSPortAdapter methods can be organized into the following categories: </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #getAdapterName() getAdapterName}
 *       <LI> {@link #getPortTypeDescription() getPortTypeDescription}
 *       <LI> {@link #getClassVersion() getClassVersion}
 *       <LI> {@link #adapterDetected() adapterDetected}
 *       <LI> {@link #getAdapterVersion() getAdapterVersion}
 *       <LI> {@link #getAdapterAddress() getAdapterAddress}
 *     </UL>
 *   <LI> <B> Port Selection </B>
 *     <UL>
 *       <LI> {@link #getPortNames() getPortNames}
 *       <LI> {@link #selectPort(String) selectPort}
 *       <LI> {@link #getPortName() getPortName}
 *       <LI> {@link #freePort() freePort}
 *     </UL>
 *   <LI> <B> Adapter Capabilities </B>
 *     <UL>
 *       <LI> {@link #canOverdrive() canOverdrive}
 *       <LI> {@link #canHyperdrive() canHyperdrive}
 *       <LI> {@link #canFlex() canFlex}
 *       <LI> {@link #canProgram() canProgram}
 *       <LI> {@link #canDeliverPower() canDeliverPower}
 *       <LI> {@link #canDeliverSmartPower() canDeliverSmartPower}
 *       <LI> {@link #canBreak() canBreak}
 *     </UL>
 *   <LI> <B> 1-Wire Network Semaphore </B>
 *     <UL>
 *       <LI> {@link #beginExclusive(boolean) beginExclusive}
 *       <LI> {@link #endExclusive() endExclusive}
 *     </UL>
 *   <LI> <B> 1-Wire Device Discovery </B>
 *     <UL>
 *       <LI> Selective Search Options
 *         <UL>
 *          <LI> {@link #targetAllFamilies() targetAllFamilies}
 *          <LI> {@link #targetFamily(int) targetFamily(int)}
 *          <LI> {@link #targetFamily(byte[]) targetFamily(byte[])}
 *          <LI> {@link #excludeFamily(int) excludeFamily(int)}
 *          <LI> {@link #excludeFamily(byte[]) excludeFamily(byte[])}
 *          <LI> {@link #setSearchOnlyAlarmingDevices() setSearchOnlyAlarmingDevices}
 *          <LI> {@link #setNoResetSearch() setNoResetSearch}
 *          <LI> {@link #setSearchAllDevices() setSearchAllDevices}
 *         </UL>
 *       <LI> Search With Automatic 1-Wire Container creation
 *         <UL>
 *          <LI> {@link #getAllDeviceContainers() getAllDeviceContainers}
 *          <LI> {@link #getFirstDeviceContainer() getFirstDeviceContainer}
 *          <LI> {@link #getNextDeviceContainer() getNextDeviceContainer}
 *         </UL>
 *       <LI> Search With NO 1-Wire Container creation
 *         <UL>
 *          <LI> {@link #findFirstDevice() findFirstDevice}
 *          <LI> {@link #findNextDevice() findNextDevice}
 *          <LI> {@link #getAddress(byte[]) getAddress(byte[])}
 *          <LI> {@link #getAddressAsLong() getAddressAsLong}
 *          <LI> {@link #getAddressAsString() getAddressAsString}
 *         </UL>
 *       <LI> Manual 1-Wire Container creation
 *         <UL>
 *          <LI> {@link #getDeviceContainer(byte[]) getDeviceContainer(byte[])}
 *          <LI> {@link #getDeviceContainer(long) getDeviceContainer(long)}
 *          <LI> {@link #getDeviceContainer(String) getDeviceContainer(String)}
 *          <LI> {@link #getDeviceContainer() getDeviceContainer()}
 *         </UL>
 *     </UL>
 *   <LI> <B> 1-Wire Network low level access (usually not called directly) </B>
 *     <UL>
 *       <LI> Device Selection and Presence Detect
 *         <UL>
 *          <LI> {@link #isPresent(byte[]) isPresent(byte[])}
 *          <LI> {@link #isPresent(long) isPresent(long)}
 *          <LI> {@link #isPresent(String) isPresent(String)}
 *          <LI> {@link #isAlarming(byte[]) isAlarming(byte[])}
 *          <LI> {@link #isAlarming(long) isAlarming(long)}
 *          <LI> {@link #isAlarming(String) isAlarming(String)}
 *          <LI> {@link #select(byte[]) select(byte[])}
 *          <LI> {@link #select(long) select(long)}
 *          <LI> {@link #select(String) select(String)}
 *         </UL>
 *       <LI> Raw 1-Wire IO
 *         <UL>
 *          <LI> {@link #reset() reset}
 *          <LI> {@link #putBit(boolean) putBit}
 *          <LI> {@link #getBit() getBit}
 *          <LI> {@link #putByte(int) putByte}
 *          <LI> {@link #getByte() getByte}
 *          <LI> {@link #getBlock(int) getBlock(int)}
 *          <LI> {@link #getBlock(byte[], int) getBlock(byte[], int)}
 *          <LI> {@link #getBlock(byte[], int, int) getBlock(byte[], int, int)}
 *          <LI> {@link #dataBlock(byte[], int, int) dataBlock(byte[], int, int)}
 *         </UL>
 *       <LI> 1-Wire Speed and Power Selection
 *         <UL>
 *          <LI> {@link #setPowerDuration(int) setPowerDuration}
 *          <LI> {@link #startPowerDelivery(int) startPowerDelivery}
 *          <LI> {@link #setProgramPulseDuration(int) setProgramPulseDuration}
 *          <LI> {@link #startProgramPulse(int) startProgramPulse}
 *          <LI> {@link #startBreak() startBreak}
 *          <LI> {@link #setPowerNormal() setPowerNormal}
 *          <LI> {@link #setSpeed(int) setSpeed}
 *          <LI> {@link #getSpeed() getSpeed}
 *         </UL>
 *     </UL>
 *   <LI> <B> Advanced </B>
 *     <UL>
 *        <LI> {@link #registerOneWireContainerClass(int, Class) registerOneWireContainerClass}
 *     </UL>
 *  </UL>
 *
 * @see com.dalsemi.onewire.OneWireAccessProvider
 * @see OneWireContainer
 *
 * @version CLSID=B53517E1-D29D-47AA-A943-47A757B536B9 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=B53517E1-D29D-47AA-A943-47A757B536B9, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class DSPortAdapter
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.adapter.DSPortAdapter objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public DSPortAdapter()
   {
   }

   DSPortAdapter(com.dalsemi.onewire.adapter.DSPortAdapter o)
   {
      this.objectInstance = o;
   }
   DSPortAdapter(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.adapter.DSPortAdapter)o);
   }

   public static final int SPEED_REGULAR
          = com.dalsemi.onewire.adapter.DSPortAdapter.SPEED_REGULAR;

   public static final int SPEED_FLEX
          = com.dalsemi.onewire.adapter.DSPortAdapter.SPEED_FLEX;

   public static final int SPEED_OVERDRIVE
          = com.dalsemi.onewire.adapter.DSPortAdapter.SPEED_OVERDRIVE;

   public static final int SPEED_HYPERDRIVE
          = com.dalsemi.onewire.adapter.DSPortAdapter.SPEED_HYPERDRIVE;

   public static final char LEVEL_NORMAL
          = com.dalsemi.onewire.adapter.DSPortAdapter.LEVEL_NORMAL;

   public static final char LEVEL_POWER_DELIVERY
          = com.dalsemi.onewire.adapter.DSPortAdapter.LEVEL_POWER_DELIVERY;

   public static final char LEVEL_BREAK
          = com.dalsemi.onewire.adapter.DSPortAdapter.LEVEL_BREAK;

   public static final char LEVEL_PROGRAM
          = com.dalsemi.onewire.adapter.DSPortAdapter.LEVEL_PROGRAM;

   public static final int RESET_NOPRESENCE
          = com.dalsemi.onewire.adapter.DSPortAdapter.RESET_NOPRESENCE;

   public static final int RESET_PRESENCE
          = com.dalsemi.onewire.adapter.DSPortAdapter.RESET_PRESENCE;

   public static final int RESET_ALARM
          = com.dalsemi.onewire.adapter.DSPortAdapter.RESET_ALARM;

   public static final int RESET_SHORT
          = com.dalsemi.onewire.adapter.DSPortAdapter.RESET_SHORT;

   public static final int CONDITION_NOW
          = com.dalsemi.onewire.adapter.DSPortAdapter.CONDITION_NOW;

   public static final int CONDITION_AFTER_BIT
          = com.dalsemi.onewire.adapter.DSPortAdapter.CONDITION_AFTER_BIT;

   public static final int CONDITION_AFTER_BYTE
          = com.dalsemi.onewire.adapter.DSPortAdapter.CONDITION_AFTER_BYTE;

   public static final int DELIVERY_HALF_SECOND
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_HALF_SECOND;

   public static final int DELIVERY_ONE_SECOND
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_ONE_SECOND;

   public static final int DELIVERY_TWO_SECONDS
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_TWO_SECONDS;

   public static final int DELIVERY_FOUR_SECONDS
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_FOUR_SECONDS;

   public static final int DELIVERY_SMART_DONE
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_SMART_DONE;

   public static final int DELIVERY_INFINITE
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_INFINITE;

   public static final int DELIVERY_CURRENT_DETECT
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_CURRENT_DETECT;

   public static final int DELIVERY_EPROM
          = com.dalsemi.onewire.adapter.DSPortAdapter.DELIVERY_EPROM;

   /**
    * Retrieves the name of the port adapter as a string.  The 'Adapter'
    * is a device that connects to a 'port' that allows one to
    * communicate with an iButton or other 1-Wire device.  As example
    * of this is 'DS9097U'.
    *
    * @return  <code>String</code> representation of the port adapter.
    */
   public java.lang.String getAdapterName()
   {      
      return objectInstance.getAdapterName();
   }

   /**
    * Retrieves a description of the port required by this port adapter.
    * An example of a 'Port' would 'serial communication port'.
    *
    * @return  <code>String</code> description of the port type required.
    */
   public java.lang.String getPortTypeDescription()
   {      
      return objectInstance.getPortTypeDescription();
   }

   /**
    * Retrieves a version string for this class.
    *
    * @return  version string
    */
   public java.lang.String getClassVersion()
   {      
      return objectInstance.getClassVersion();
   }

   /**
    * Retrieves a list of the platform appropriate port names for this
    * adapter.  A port must be selected with the method 'selectPort'
    * before any other communication methods can be used.  Using
    * a communcation method before 'selectPort' will result in
    * a <code>OneWireException</code> exception.
    *
    * @return  <code>Enumeration</code> of type <code>String</code> that contains the port
    * names
    */
   public StringEnumeration getPortNames()
   {      
      return new StringEnumeration().setupObject(objectInstance.getPortNames());
   }

   /**
    * Registers a user provided <code>OneWireContainer</code> class.
    * Using this method will override the Dallas Semiconductor provided
    * container class when using the getDeviceContainer() method.  The
    * registered container state is only stored for the current
    * instance of <code>DSPortAdapter</code>, and is not statically shared.
    * The <code>OneWireContainerClass</code> must extend
    * <code>OneWireContainer</code> otherwise a <code>ClassCastException</code>
    * will be thrown.
    * The older duplicate family will be removed from registration when
    * a collision occurs.
    * Passing null as a parameter for the <code>OneWireContainerClass</code> will result
    * in the removal of any entry associated with the family.
    *
    * @param family   the code of the family type to associate with this class.
    * @param OneWireContainerClass  User provided class
    *
    * @throws OneWireException If <code>OneWireContainerClass</code> is not found.
    * @throws ClassCastException If user supplied <code>OneWireContainer</code> does not
    * extend <code>
    */
   public void registerOneWireContainerClass(int a0, java.lang.Class a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      objectInstance.registerOneWireContainerClass(a0, a1);
   }

   /**
    * Specifies a platform appropriate port name for this adapter.  Note that
    * even though the port has been selected, it's ownership may be relinquished
    * if it is not currently held in a 'exclusive' block.  This class will then
    * try to re-aquire the port when needed.  If the port cannot be re-aquired
    * ehen the exception <code>PortInUseException</code> will be thrown.
    *
    * @param  portName  name of the target port, retrieved from
    * getPortNames()
    *
    * @return <code>true</code> if the port was aquired, <code>false</code>
    * if the port is not available.
    *
    * @throws OneWireIOException If port does not exist, or unable to communicate with port.
    * @throws OneWireException If port does not exist
    */
   public boolean selectPort(java.lang.String portName)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.selectPort(portName);
   }

   /**
    * Frees ownership of the selected port, if it is currently owned, back
    * to the system.  This should only be called if the recently
    * selected port does not have an adapter, or at the end of
    * your application's use of the port.
    *
    * @throws OneWireException If port does not exist
    */
   public void freePort()
      throws com.dalsemi.onewire.OneWireException
   {      
      objectInstance.freePort();
   }

   /**
    * Retrieves the name of the selected port as a <code>String</code>.
    *
    * @return  <code>String</code> of selected port
    *
    * @throws OneWireException if valid port not yet selected
    */
   public java.lang.String getPortName()
      throws com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.getPortName();
   }

   /**
    * Detects adapter presence on the selected port.
    *
    * @return  <code>true</code> if the adapter is confirmed to be connected to
    * the selected port, <code>false</code> if the adapter is not connected.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean adapterDetected()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.adapterDetected();
   }

   /**
    * Retrieves the version of the adapter.
    *
    * @return  <code>String</code> of the adapter version.  It will return
    * "<na>" if the adapter version is not or cannot be known.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public java.lang.String getAdapterVersion()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.getAdapterVersion();
   }

   /**
    * Retrieves the address of the adapter, if it has one.
    *
    * @return  <code>String</code> of the adapter address.  It will return "<na>" if
    * the adapter does not have an address.  The address is a string representation of an
    * 1-Wire address.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    * @see    Address
    */
   public java.lang.String getAdapterAddress()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.getAdapterAddress();
   }

   /**
    * Returns whether adapter can physically support overdrive mode.
    *
    * @return  <code>true</code> if this port adapter can do OverDrive,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canOverdrive()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canOverdrive();
   }

   /**
    * Returns whether the adapter can physically support hyperdrive mode.
    *
    * @return  <code>true</code> if this port adapter can do HyperDrive,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canHyperdrive()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canHyperdrive();
   }

   /**
    * Returns whether the adapter can physically support flex speed mode.
    *
    * @return  <code>true</code> if this port adapter can do flex speed,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canFlex()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canFlex();
   }

   /**
    * Returns whether adapter can physically support 12 volt power mode.
    *
    * @return  <code>true</code> if this port adapter can do Program voltage,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canProgram()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canProgram();
   }

   /**
    * Returns whether the adapter can physically support strong 5 volt power
    * mode.
    *
    * @return  <code>true</code> if this port adapter can do strong 5 volt
    * mode, <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canDeliverPower()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canDeliverPower();
   }

   /**
    * Returns whether the adapter can physically support "smart" strong 5
    * volt power mode.  "smart" power delivery is the ability to deliver
    * power until it is no longer needed.  The current drop it detected
    * and power delivery is stopped.
    *
    * @return  <code>true</code> if this port adapter can do "smart" strong
    * 5 volt mode, <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canDeliverSmartPower()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canDeliverSmartPower();
   }

   /**
    * Returns whether adapter can physically support 0 volt 'break' mode.
    *
    * @return  <code>true</code> if this port adapter can do break,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error with the adapter
    * @throws OneWireException on a setup error with the 1-Wire
    *         adapter
    */
   public boolean canBreak()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.canBreak();
   }

   /**
    * Returns an enumeration of <code>OneWireContainer</code> objects corresponding
    * to all of the iButtons or 1-Wire devices found on the 1-Wire Network.
    * If no devices are found, then an empty enumeration will be returned.
    * In most cases, all further communication with the device is done
    * through the OneWireContainer.
    *
    * @return  <code>Enumeration</code> of <code>OneWireContainer</code> objects
    * found on the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public OneWireContainerEnumeration getAllDeviceContainers()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new OneWireContainerEnumeration().setupObject(objectInstance.getAllDeviceContainers());
   }

   /**
    * Returns a <code>OneWireContainer</code> object corresponding to the first iButton
    * or 1-Wire device found on the 1-Wire Network. If no devices are found,
    * then a <code>null</code> reference will be returned. In most cases, all further
    * communication with the device is done through the <code>OneWireContainer</code>.
    *
    * @return  The first <code>OneWireContainer</code> object found on the
    * 1-Wire Network, or <code>null</code> if no devices found.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public OneWireContainer getFirstDeviceContainer()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new OneWireContainer(objectInstance.getFirstDeviceContainer());
   }

   /**
    * Returns a <code>OneWireContainer</code> object corresponding to the next iButton
    * or 1-Wire device found. The previous 1-Wire device found is used
    * as a starting point in the search.  If no devices are found,
    * then a <code>null</code> reference will be returned. In most cases, all further
    * communication with the device is done through the <code>OneWireContainer</code>.
    *
    * @return  The next <code>OneWireContainer</code> object found on the
    * 1-Wire Network, or <code>null</code> if no iButtons found.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public OneWireContainer getNextDeviceContainer()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new OneWireContainer(objectInstance.getNextDeviceContainer());
   }

   /**
    * Returns <code>true</code> if the first iButton or 1-Wire device
    * is found on the 1-Wire Network.
    * If no devices are found, then <code>false</code> will be returned.
    *
    * @return  <code>true</code> if an iButton or 1-Wire device is found.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public boolean findFirstDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.findFirstDevice();
   }

   /**
    * Returns <code>true</code> if the next iButton or 1-Wire device
    * is found. The previous 1-Wire device found is used
    * as a starting point in the search.  If no more devices are found
    * then <code>false</code> will be returned.
    *
    * @return  <code>true</code> if an iButton or 1-Wire device is found.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public boolean findNextDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.findNextDevice();
   }

   /**
    * Copies the 'current' 1-Wire device address being used by the adapter into
    * the array.  This address is the last iButton or 1-Wire device found
    * in a search (findNextDevice()...).
    * This method copies into a user generated array to allow the
    * reuse of the buffer.  When searching many iButtons on the one
    * wire network, this will reduce the memory burn rate.
    *
    * @param  address An array to be filled with the current iButton address.
    * @see    Address
    */
   public void getAddress(ByteArray address)
   {      
      objectInstance.getAddress(address.array);
   }

   /**
    * Gets the 'current' 1-Wire device address being used by the adapter as a long.
    * This address is the last iButton or 1-Wire device found
    * in a search (findNextDevice()...).
    *
    * @return <code>long</code> representation of the iButton address
    * @see    Address
    */
   public String getAddressAsLong()
   {      
      return ""+objectInstance.getAddressAsLong();
   }

   /**
    * Gets the 'current' 1-Wire device address being used by the adapter as a String.
    * This address is the last iButton or 1-Wire device found
    * in a search (findNextDevice()...).
    *
    * @return <code>String</code> representation of the iButton address
    * @see    Address
    */
   public java.lang.String getAddressAsString()
   {      
      return objectInstance.getAddressAsString();
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present on
    * the 1-Wire Network. This does not affect the 'current' device
    * state information used in searches (findNextDevice...).
    *
    * @param  address  device address to verify is present
    *
    * @return  <code>true</code> if device is present, else
    *         <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isPresentFromBytes(ByteArray address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isPresent(address.array);
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present on
    * the 1-Wire Network. This does not affect the 'current' device
    * state information used in searches (findNextDevice...).
    *
    * @param  address  device address to verify is present
    *
    * @return  <code>true</code> if device is present, else
    *         <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isPresentFromLong(String address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isPresent(Long.parseLong(address));
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present on
    * the 1-Wire Network. This does not affect the 'current' device
    * state information used in searches (findNextDevice...).
    *
    * @param  address  device address to verify is present
    *
    * @return  <code>true</code> if device is present, else
    *         <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isPresent(java.lang.String address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isPresent(address);
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present
    * on the 1-Wire Network and in an alarm state. This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * @param  address  device address to verify is present and alarming
    *
    * @return  <code>true</code> if device is present and alarming, else
    * <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isAlarmingFromBytes(ByteArray address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isAlarming(address.array);
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present
    * on the 1-Wire Network and in an alarm state. This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * @param  address  device address to verify is present and alarming
    *
    * @return  <code>true</code> if device is present and alarming, else
    * <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isAlarmingFromLong(String address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isAlarming(Long.parseLong(address));
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present
    * on the 1-Wire Network and in an alarm state. This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * @param  address  device address to verify is present and alarming
    *
    * @return  <code>true</code> if device is present and alarming, else
    * <code>false</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see    Address
    */
   public boolean isAlarming(java.lang.String address)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isAlarming(address);
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @return  <code>true</code> if device address was sent, <code>false</code>
    * otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public boolean selectFromBytes(ByteArray a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.select(a0.array);
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @return  <code>true</code> if device address was sent,<code>false</code>
    * otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public boolean selectFromLong(String a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.select(Long.parseLong(a0));
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @return  <code>true</code> if device address was sent,<code>false</code>
    * otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public boolean select(java.lang.String a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.select(a0);
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * In addition, this method asserts that the select did find some
    * devices on the 1-Wire net.  If no devices were found, a OneWireException
    * is thrown.
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @throws OneWireIOException on a 1-Wire communication error, or if their
    *         are no devices on the 1-Wire net.
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public void assertSelectFromBytes(ByteArray a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.assertSelect(a0.array);
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * In addition, this method asserts that the select did find some
    * devices on the 1-Wire net.  If no devices were found, a OneWireException
    * is thrown.
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @return  <code>true</code> if device address was sent,<code>false</code>
    * otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error, or if their
    *         are no devices on the 1-Wire net.
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public void assertSelectFromLong(String a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.assertSelect(Long.parseLong(a0));
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * In addition, this method asserts that the select did find some
    * devices on the 1-Wire net.  If no devices were found, a OneWireException
    * is thrown.
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @throws OneWireIOException on a 1-Wire communication error, or if their
    *         are no devices on the 1-Wire net.
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *
    * @see DSPortAdapter#isPresent(byte[])
    * @see    Address
    */
   public void assertSelect(java.lang.String a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.assertSelect(a0);
   }

   /**
    * Sets the 1-Wire Network search to find only iButtons and 1-Wire
    * devices that are in an 'Alarm' state that signals a need for
    * attention.  Not all iButton types
    * have this feature.  Some that do: DS1994, DS1920, DS2407.
    * This selective searching can be canceled with the
    * 'setSearchAllDevices()' method.
    *
    * @see #setNoResetSearch
    */
   public void setSearchOnlyAlarmingDevices()
   {      
      objectInstance.setSearchOnlyAlarmingDevices();
   }

   /**
    * Sets the 1-Wire Network search to not perform a 1-Wire
    * reset before a search.  This feature is chiefly used with
    * the DS2409 1-Wire coupler.
    * The normal reset before each search can be restored with the
    * 'setSearchAllDevices()' method.
    */
   public void setNoResetSearch()
   {      
      objectInstance.setNoResetSearch();
   }

   /**
    * Sets the 1-Wire Network search to find all iButtons and 1-Wire
    * devices whether they are in an 'Alarm' state or not and
    * restores the default setting of providing a 1-Wire reset
    * command before each search. (see setNoResetSearch() method).
    *
    * @see #setNoResetSearch
    */
   public void setSearchAllDevices()
   {      
      objectInstance.setSearchAllDevices();
   }

   /**
    * Removes any selectivity during a search for iButtons or 1-Wire devices
    * by family type.  The unique address for each iButton and 1-Wire device
    * contains a family descriptor that indicates the capabilities of the
    * device.
    * @see    #targetFamily
    * @see    #targetFamily(byte[])
    * @see    #excludeFamily
    * @see    #excludeFamily(byte[])
    */
   public void targetAllFamilies()
   {      
      objectInstance.targetAllFamilies();
   }

   /**
    * Takes an integer to selectively search for this desired family type.
    * If this method is used, then no devices of other families will be
    * found by any of the search methods.
    *
    * @param  family   the code of the family type to target for searches
    * @see    Address
    * @see    #targetAllFamilies
    */
   public void targetFamily(int family)
   {      
      objectInstance.targetFamily(family);
   }

   /**
    * Takes an array of bytes to use for selectively searching for acceptable
    * family codes.  If used, only devices with family codes in this array
    * will be found by any of the search methods.
    *
    * @param  family  array of the family types to target for searches
    * @see    Address
    * @see    #targetAllFamilies
    */
   public void targetFamilyFromBytes(ByteArray family )
   {      
      objectInstance.targetFamily(family .array);
   }

   /**
    * Takes an integer family code to avoid when searching for iButtons.
    * or 1-Wire devices.
    * If this method is used, then no devices of this family will be
    * found by any of the search methods.
    *
    * @param  family   the code of the family type NOT to target in searches
    * @see    Address
    * @see    #targetAllFamilies
    */
   public void excludeFamily(int family)
   {      
      objectInstance.excludeFamily(family);
   }

   /**
    * Takes an array of bytes containing family codes to avoid when finding
    * iButtons or 1-Wire devices.  If used, then no devices with family
    * codes in this array will be found by any of the search methods.
    *
    * @param  family  array of family cods NOT to target for searches
    * @see    Address
    * @see    #targetAllFamilies
    */
   public void excludeFamilyFromBytes(ByteArray family )
   {      
      objectInstance.excludeFamily(family .array);
   }

   /**
    * Gets exclusive use of the 1-Wire to communicate with an iButton or
    * 1-Wire Device.
    * This method should be used for critical sections of code where a
    * sequence of commands must not be interrupted by communication of
    * threads with other iButtons, and it is permissible to sustain
    * a delay in the special case that another thread has already been
    * granted exclusive access and this access has not yet been
    * relinquished. <p>
    *
    * It can be called through the OneWireContainer
    * class by the end application if they want to ensure exclusive
    * use.  If it is not called around several methods then it
    * will be called inside each method.
    *
    * @param blocking <code>true</code> if want to block waiting
    *                 for an excluse access to the adapter
    * @return <code>true</code> if blocking was false and a
    *         exclusive session with the adapter was aquired
    *
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public boolean beginExclusive(boolean blocking)
      throws com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.beginExclusive(blocking);
   }

   /**
    * Relinquishes exclusive control of the 1-Wire Network.
    * This command dynamically marks the end of a critical section and
    * should be used when exclusive control is no longer needed.
    */
   public void endExclusive()
   {      
      objectInstance.endExclusive();
   }

   /**
    * Sends a bit to the 1-Wire Network.
    *
    * @param  bitValue  the bit value to send to the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void putBit(boolean bitValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.putBit(bitValue);
   }

   /**
    * Gets a bit from the 1-Wire Network.
    *
    * @return  the bit value recieved from the the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public boolean getBit()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.getBit();
   }

   /**
    * Sends a byte to the 1-Wire Network.
    *
    * @param  byteValue  the byte value to send to the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void putByte(int byteValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.putByte(byteValue);
   }

   /**
    * Gets a byte from the 1-Wire Network.
    *
    * @return  the byte value received from the the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public int getByte()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.getByte();
   }

   /**
    * Gets a block of data from the 1-Wire Network.
    *
    * @param  len  length of data bytes to receive
    *
    * @return  the data received from the 1-Wire Network.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public ByteArray getBlock(int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(objectInstance.getBlock(len));
   }

   /**
    * Gets a block of data from the 1-Wire Network and write it into
    * the provided array.
    *
    * @param  arr     array in which to write the received bytes
    * @param  len     length of data bytes to receive
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void getBlock(ByteArray arr, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.getBlock(arr.array, len);
   }

   /**
    * Gets a block of data from the 1-Wire Network and write it into
    * the provided array.
    *
    * @param  arr     array in which to write the received bytes
    * @param  off     offset into the array to start
    * @param  len     length of data bytes to receive
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void getBlock(ByteArray arr, int off, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.getBlock(arr.array, off, len);
   }

   /**
    * Sends a block of data and returns the data received in the same array.
    * This method is used when sending a block that contains reads and writes.
    * The 'read' portions of the data block need to be pre-loaded with 0xFF's.
    * It starts sending data from the index at offset 'off' for length 'len'.
    *
    * @param  dataBlock  array of data to transfer to and from the 1-Wire Network.
    * @param  off        offset into the array of data to start
    * @param  len        length of data to send / receive starting at 'off'
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void dataBlock(ByteArray dataBlock , int off, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.dataBlock(dataBlock .array, off, len);
   }

   /**
    * Sends a Reset to the 1-Wire Network.
    *
    * @return  the result of the reset. Potential results are:
    * <ul>
    * <li> 0 (RESET_NOPRESENCE) no devices present on the 1-Wire Network.
    * <li> 1 (RESET_PRESENCE) normal presence pulse detected on the 1-Wire
    *        Network indicating there is a device present.
    * <li> 2 (RESET_ALARM) alarming presence pulse detected on the 1-Wire
    *        Network indicating there is a device present and it is in the
    *        alarm condition.  This is only provided by the DS1994/DS2404
    *        devices.
    * <li> 3 (RESET_SHORT) indicates 1-Wire appears shorted.  This can be
    *        transient conditions in a 1-Wire Network.  Not all adapter types
    *        can detect this condition.
    * </ul>
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public int reset()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.reset();
   }

   /**
    * Sets the duration to supply power to the 1-Wire Network.
    * This method takes a time parameter that indicates the program
    * pulse length when the method startPowerDelivery().<p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() and canDeliverSmartPower()
    * method to check it's availability. <p>
    *
    * @param timeFactor
    * <ul>
    * <li>   0 (DELIVERY_HALF_SECOND) provide power for 1/2 second.
    * <li>   1 (DELIVERY_ONE_SECOND) provide power for 1 second.
    * <li>   2 (DELIVERY_TWO_SECONDS) provide power for 2 seconds.
    * <li>   3 (DELIVERY_FOUR_SECONDS) provide power for 4 seconds.
    * <li>   4 (DELIVERY_SMART_DONE) provide power until the
    *          the device is no longer drawing significant power.
    * <li>   5 (DELIVERY_INFINITE) provide power until the
    *          setPowerNormal() method is called.
    * </ul>
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void setPowerDuration(int timeFactor)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.setPowerDuration(timeFactor);
   }

   /**
    * Sets the 1-Wire Network voltage to supply power to a 1-Wire device.
    * This method takes a time parameter that indicates whether the
    * power delivery should be done immediately, or after certain
    * conditions have been met. <p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() and canDeliverSmartPower()
    * method to check it's availability. <p>
    *
    * @param changeCondition
    * <ul>
    * <li>   0 (CONDITION_NOW) operation should occur immediately.
    * <li>   1 (CONDITION_AFTER_BIT) operation should be pending
    *           execution immediately after the next bit is sent.
    * <li>   2 (CONDITION_AFTER_BYTE) operation should be pending
    *           execution immediately after next byte is sent.
    * </ul>
    *
    * @return <code>true</code> if the voltage change was successful,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public boolean startPowerDelivery(int changeCondition)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.startPowerDelivery(changeCondition);
   }

   /**
    * Sets the duration for providing a program pulse on the
    * 1-Wire Network.
    * This method takes a time parameter that indicates the program
    * pulse length when the method startProgramPulse().<p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() method to check it's
    * availability. <p>
    *
    * @param timeFactor
    * <ul>
    * <li>   7 (DELIVERY_EPROM) provide program pulse for 480 microseconds
    * <li>   5 (DELIVERY_INFINITE) provide power until the
    *          setPowerNormal() method is called.
    * </ul>
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    */
   public void setProgramPulseDuration(int timeFactor)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.setProgramPulseDuration(timeFactor);
   }

   /**
    * Sets the 1-Wire Network voltage to eprom programming level.
    * This method takes a time parameter that indicates whether the
    * power delivery should be done immediately, or after certain
    * conditions have been met. <p>
    *
    * Note: to avoid getting an exception,
    * use the canProgram() method to check it's
    * availability. <p>
    *
    * @param changeCondition
    * <ul>
    * <li>   0 (CONDITION_NOW) operation should occur immediately.
    * <li>   1 (CONDITION_AFTER_BIT) operation should be pending
    *           execution immediately after the next bit is sent.
    * <li>   2 (CONDITION_AFTER_BYTE) operation should be pending
    *           execution immediately after next byte is sent.
    * </ul>
    *
    * @return <code>true</code> if the voltage change was successful,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *         or the adapter does not support this operation
    */
   public boolean startProgramPulse(int changeCondition)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.startProgramPulse(changeCondition);
   }

   /**
    * Sets the 1-Wire Network voltage to 0 volts.  This method is used
    * rob all 1-Wire Network devices of parasite power delivery to force
    * them into a hard reset.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *         or the adapter does not support this operation
    */
   public void startBreak()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.startBreak();
   }

   /**
    * Sets the 1-Wire Network voltage to normal level.  This method is used
    * to disable 1-Wire conditions created by startPowerDelivery and
    * startProgramPulse.  This method will automatically be called if
    * a communication method is called while an outstanding power
    * command is taking place.
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *         or the adapter does not support this operation
    */
   public void setPowerNormal()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.setPowerNormal();
   }

   /**
    * Sets the new speed of data
    * transfer on the 1-Wire Network. <p>
    *
    * @param speed
    * <ul>
    * <li>     0 (SPEED_REGULAR) set to normal communciation speed
    * <li>     1 (SPEED_FLEX) set to flexible communciation speed used
    *            for long lines
    * <li>     2 (SPEED_OVERDRIVE) set to normal communciation speed to
    *            overdrive
    * <li>     3 (SPEED_HYPERDRIVE) set to normal communciation speed to
    *            hyperdrive
    * <li>    >3 future speeds
    * </ul>
    *
    * @throws OneWireIOException on a 1-Wire communication error
    * @throws OneWireException on a setup error with the 1-Wire adapter
    *         or the adapter does not support this operation
    */
   public void setSpeed(int speed)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.setSpeed(speed);
   }

   /**
    * Returns the current data transfer speed on the 1-Wire Network. <p>
    *
    * @return <code>int</code> representing the current 1-Wire speed
    * <ul>
    * <li>     0 (SPEED_REGULAR) set to normal communication speed
    * <li>     1 (SPEED_FLEX) set to flexible communication speed used
    *            for long lines
    * <li>     2 (SPEED_OVERDRIVE) set to normal communication speed to
    *            overdrive
    * <li>     3 (SPEED_HYPERDRIVE) set to normal communication speed to
    *            hyperdrive
    * <li>    >3 future speeds
    * </ul>
    */
   public int getSpeed()
   {      
      return objectInstance.getSpeed();
   }

   /**
    * Constructs a <code>OneWireContainer</code> object with a user supplied 1-Wire network address.
    *
    * @param  address  device address with which to create a new container
    *
    * @return  The <code>OneWireContainer</code> object
    * @see    Address
    */
   public OneWireContainer getDeviceContainerFromBytes(ByteArray address)
   {      
      return new OneWireContainer(objectInstance.getDeviceContainer(address.array));
   }

   /**
    * Constructs a <code>OneWireContainer</code> object with a user supplied 1-Wire network address.
    *
    * @param  address  device address with which to create a new container
    *
    * @return  The <code>OneWireContainer</code> object
    * @see    Address
    */
   public OneWireContainer getDeviceContainerFromLong(String address)
   {      
      return new OneWireContainer(objectInstance.getDeviceContainer(Long.parseLong(address)));
   }

   /**
    * Constructs a <code>OneWireContainer</code> object with a user supplied 1-Wire network address.
    *
    * @param  address  device address with which to create a new container
    *
    * @return  The <code>OneWireContainer</code> object
    * @see    Address
    */
   public OneWireContainer getDeviceContainer(java.lang.String address)
   {      
      return new OneWireContainer(objectInstance.getDeviceContainer(address));
   }

   /**
    * Constructs a <code>OneWireContainer</code> object with a user supplied 1-Wire network address.
    *
    * @param  address  device address with which to create a new container
    *
    * @return  The <code>OneWireContainer</code> object
    * @see    Address
    */
   public OneWireContainer getDeviceContainer()
   {      
      return new OneWireContainer(objectInstance.getDeviceContainer());
   }

   /**
    * Returns true if the given object is the same or equivalent
    * to this DSPortAdapter.
    *
    * @param o the Object to compare this DSPortAdapter to
    * @return true if the given object is the same or equivalent
    * to this DSPortAdapter.
    */
   public boolean equals(java.lang.Object o)
   {      
      return objectInstance.equals(o);
   }

   /**
    * Returns a string representation of this DSPortAdapter, in the format
    * of "<adapter name> <port name>".
    *
    * @return a string representation of this DSPortAdapter
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   DSPortAdapter setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.adapter.DSPortAdapter)o;
      return this;
   }
}
