// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Memory bank class for the Scratchpad section of SHA EEPROM iButtons and
 * 1-Wire devices with SHA write-protected memory pages.
 *
 *  @version    CLSID=D72C0310-9F85-4B65-8D8E-F22EDD80DAA0 - 1.00, 11 Aug 2002
 *  @author     SH
 * @com.register ( clsid=D72C0310-9F85-4B65-8D8E-F22EDD80DAA0, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class MemoryBankScratchSHAEE
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.MemoryBankScratchSHAEE objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public MemoryBankScratchSHAEE()
   {
   }

   MemoryBankScratchSHAEE(com.dalsemi.onewire.container.MemoryBankScratchSHAEE o)
   {
      this.objectInstance = o;
   }
   MemoryBankScratchSHAEE(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.MemoryBankScratchSHAEE)o);
   }

   public static final byte LOAD_FIRST_SECRET
          = com.dalsemi.onewire.container.MemoryBankScratchSHAEE.LOAD_FIRST_SECRET;

   public static final byte COMPUTE_NEXT_SECRET
          = com.dalsemi.onewire.container.MemoryBankScratchSHAEE.COMPUTE_NEXT_SECRET;

   public static final byte REFRESH_SCRATCHPAD
          = com.dalsemi.onewire.container.MemoryBankScratchSHAEE.REFRESH_SCRATCHPAD;

   /**
    * Memory bank contstuctor.  Requires reference to the OneWireContainer
    * this memory bank resides on.
    */
   public void createNewInstance(OneWireContainer33 ibutton)
   {      
      objectInstance = new com.dalsemi.onewire.container.MemoryBankScratchSHAEE(((com.dalsemi.onewire.container.OneWireContainer33)ibutton.objectInstance));
   }

   /**
    * Read a complete memory page with CRC verification provided by the
    * device.  Not supported by all devices.  See the method
    * 'hasPageAutoCRC()'.
    *
    * @param  page          page number to read
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       readPagePacket() continious where the last one
    *                       stopped and it is inside a
    *                       'beginExclusive/endExclusive' block.
    * @param  readBuf       byte array to put data read. Must have at least
    *                       'getMaxPacketDataLength()' elements.
    * @param  offset        offset into readBuf to place data
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readPageCRC(int page, boolean readContinue, ByteArray readBuf, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readPageCRC(page, readContinue, readBuf.array, offset);
   }

   /**
    * Read a complete memory page with CRC verification provided by the
    * device with extra information.  Not supported by all devices.
    * See the method 'hasPageAutoCRC()'.
    * See the method 'hasExtraInfo()' for a description of the optional
    * extra information.
    *
    * @param  page          page number to read
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       readPagePacket() continious where the last one
    *                       stopped and it is inside a
    *                       'beginExclusive/endExclusive' block.
    * @param  readBuf       byte array to put data read. Must have at least
    *                       'getMaxPacketDataLength()' elements.
    * @param  offset        offset into readBuf to place data
    * @param  extraInfo     byte array to put extra info read into
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readPageCRC(int page, boolean readContinue, ByteArray readBuf, int offset, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readPageCRC(page, readContinue, readBuf.array, offset, extraInfo.array);
   }

   /**
    * Read the scratchpad page of memory from a NVRAM device
    * This method reads and returns the entire scratchpad after the byte
    * offset regardless of the actual ending offset
    *
    * @param  readBuf       byte array to place read data into
    *                       length of array is always pageLength.
    * @param  offset        offset into readBuf to pug data
    * @param  len           length in bytes to read
    * @param  extraInfo     byte array to put extra info read into
    *                       (TA1, TA2, e/s byte)
    *                       length of array is always extraInfoLength.
    *                       Can be 'null' if extra info is not needed.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readScratchpad(ByteArray readBuf, int offset, int len, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readScratchpad(readBuf.array, offset, len, extraInfo.array);
   }

   /**
    * Copy the scratchpad page to memory.
    *
    * @param  addr the address to copy the data to
    * @param  len length byte is ignored, must always be 8.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void copyScratchpad(int addr, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.copyScratchpad(addr, len);
   }

   /**
    * Copy the scratchpad page to memory.
    *
    * @param  addr the address to copy to
    * @param  scratchpad the scratchpad contents that will be copied
    * @param  offset the offset into scratchpad byte[] where scratchpad data begins
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void copyScratchpad(int addr, ByteArray scratchpad, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.copyScratchpad(addr, scratchpad.array, offset);
   }

   /**
    * Copy the scratchpad page to memory.
    *
    * @param  addr the address to copy to
    * @param  scratchpad the scratchpad contents that will be copied
    * @param  scratchpadOffset the offset into scratchpad byte[] where scratchpad data begins
    * @param  pageData the data on the page of memory to be written to
    * @param  pageDataOffset the offset into pageData byte[] where pageData begins
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void copyScratchpad(int addr, ByteArray scratchpad, int scratchpadOffset, ByteArray pageData, int pageDataOffset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.copyScratchpad(addr, scratchpad.array, scratchpadOffset, pageData.array, pageDataOffset);
   }

   /**
    * Copy all 8 bytes of the Sratch Pad to a certain address in memory
    * using the provided authorization MAC
    *
    * @param addr the address to copy the data to
    * @param authMAC byte[] containing write authorization MAC
    * @param authOffset offset into authMAC where authorization MAC begins
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void copyScratchpadWithMAC(int addr, ByteArray authMAC, int authOffset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.copyScratchpadWithMAC(addr, authMAC.array, authOffset);
   }

   /**
    * Write to the scratchpad page of memory a NVRAM device.
    *
    * @param  addr physical address to copy data to
    * @param  writeBuf byte array containing data to write
    * @param  offset offset into readBuf to place data
    * @param  len length in bytes to write
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void writeScratchpad(int addr, ByteArray writeBuf, int offset, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.writeScratchpad(addr, writeBuf.array, offset, len);
   }

   /**
    * Write  memory in the current bank.  It is recommended that
    * when writing  data that some structure in the data is created
    * to provide error free reading back with read().  Or the
    * method 'writePagePacket()' could be used which automatically
    * wraps the data in a length and CRC.
    *
    * When using on Write-Once devices care must be taken to write into
    * into empty space.  If write() is used to write over an unlocked
    * page on a Write-Once device it will fail.  If write verification
    * is turned off with the method 'setWriteVerification(false)' then
    * the result will be an 'AND' of the existing data and the new data.
    *
    * @param  addr          the address to write to
    * @param  writeBuf      byte array containing data to write
    * @param  offset        offset into writeBuf to get data
    * @param  len           length in bytes to write
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void write(int addr, ByteArray writeBuf, int offset, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.write(addr, writeBuf.array, offset, len);
   }

   /**
    *  Load First Secret for the DS2432.  Loads the specified data
    *  to the specified location.  If the address is data memory
    *  (instead of secret memory), this command must have been preceded by
    *  a Refresh Scratchpad command for it to be successful.
    *
    * @param addr the address to write the data to
    * @param data the data to 'load' with the Load First Secret command
    * @param offset the offset to use for reading the data byte[]
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void loadFirstSecret(int addr, ByteArray data, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.loadFirstSecret(addr, data.array, offset);
   }

   /**
    *  Load First Secret for the DS2432.  Loads the specified data
    *  to the specified location.  If the address is data memory
    *  (instead of secret memory), this command must have been preceded by
    *  a Refresh Scratchpad command for it to be successful.
    *
    * @param addr the address to write the data to
    * @param data the data to 'load' with the Load First Secret command
    * @param offset the offset to use for reading the data byte[]
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void loadFirstSecret(int addr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.loadFirstSecret(addr);
   }

   /**
    * Computes the next secret.
    *
    * @param addr the physical address of the page to use for secret computation
    * @param partialsecret byte array containing next partial secret for writing to the scratchpad
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void computeNextSecret(int addr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.computeNextSecret(addr);
   }

   /**
    * Computes the next secret.
    *
    * @param addr the physical address of the page to use for secret computation
    * @param partialsecret byte array containing next partial secret for writing to the scratchpad
    * @param offset into partialsecret byte array to start reading
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void computeNextSecret(int addr, ByteArray partialsecret, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.computeNextSecret(addr, partialsecret.array, offset);
   }

   /**
    * Refreshes the scratchpad for DS1961S.  Command has no effect on DS2432
    * devices.  After this command is executed, the data at the address
    * specified will be loaded into the scratchpad.  The Load First Secret
    * command can then be used to re-write the data back to the page, correcting
    * any weakly-programmed EEPROM bits.
    *
    * @param addr the address to load the data from into the scratchpad
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void refreshScratchpad(int addr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.refreshScratchpad(addr);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   MemoryBankScratchSHAEE setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.MemoryBankScratchSHAEE)o;
      return this;
   }
}
