// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Instances of the 1-Wire file descriptor class serve as an opaque handle
 * to the underlying machine-specific structure representing an open
 * file, an open socket, or another source or sink of bytes. The
 * main practical use for a file descriptor is to create a
 * <code>OWFileInputStream</code> or <code>OWFileOutputStream</code> to
 * contain it.
 * <p>
 * Applications should not create their own file descriptors.
 *
 * @author  DS
 * @version CLSID=0B882ED5-740F-440A-8C81-536FB36D406A -  0.01, 1 June 2001
 * @see     OWFile
 * @see     OWFileInputStream
 * @see     OWFileOutputStream
 * @com.register ( clsid=0B882ED5-740F-440A-8C81-536FB36D406A, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OWFileDescriptor
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.application.file.OWFileDescriptor objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public OWFileDescriptor()
   {
      this.objectInstance = new com.dalsemi.onewire.application.file.OWFileDescriptor();
   }

   OWFileDescriptor(com.dalsemi.onewire.application.file.OWFileDescriptor o)
   {
      this.objectInstance = o;
   }
   OWFileDescriptor(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.file.OWFileDescriptor)o);
   }

   /**
    * Tests if this file descriptor object is valid.
    *
    * @return  <code>true</code> if the file descriptor object represents a
    *          valid, open file, socket, or other active I/O connection;
    *          <code>false</code> otherwise.
    */
   public boolean valid()
   {      
      return objectInstance.valid();
   }

   /**
    * Force all system buffers to synchronize with the underlying
    * device.  This method returns after all modified data and
    * attributes of this FileDescriptor have been written to the
    * relevant device(s).  In particular, if this FileDescriptor
    * refers to a physical storage medium, such as a file in a file
    * system, sync will not return until all in-memory modified copies
    * of buffers associated with this FileDesecriptor have been
    * written to the physical medium.
    *
    * sync is meant to be used by code that requires physical
    * storage (such as a file) to be in a known state  For
    * example, a class that provided a simple transaction facility
    * might use sync to ensure that all changes to a file caused
    * by a given transaction were recorded on a storage medium.
    *
    * sync only affects buffers downstream of this FileDescriptor.  If
    * any in-memory buffering is being done by the application (for
    * example, by a BufferedOutputStream object), those buffers must
    * be flushed into the OWFileDescriptor (for example, by invoking
    * OutputStream.flush) before that data will be affected by sync.
    *
    * <p>This method may be called multiple times if the source of
    * OWSyncFailedException has been rectified (1-Wire device was
    * reattached to the network).
    *
    * @exception OWSyncFailedException
    *        Thrown when the buffers cannot be flushed,
    *        or because the system cannot guarantee that all the
    *        buffers have been synchronized with physical media.
    */
   public void sync()
      throws com.dalsemi.onewire.application.file.OWSyncFailedException
   {      
      objectInstance.sync();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OWFileDescriptor setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.file.OWFileDescriptor)o;
      return this;
   }
}
