// COM proxy class, output from FunctionList.js
package owapi;
/**
 * A <code>OWFileInputStream</code> obtains input bytes
 * from a file in a 1-Wire Filesystem. What files
 * are available depends on the 1-Wire device.
 *
 * <p> Note that the 1-Wire File system can reside across multiple 1-Wire
 *  devices.  In this case only one of the devices need be supplied to the
 *  constructor.  Each device in a multi-device file system contains
 *  information to reacquire the entire list.
 *
 * <p>  File and directory <b> name </b> limitations
 * <ul>
 * <li> File/directory names limited to 4 characters not including extension
 * <li> File/directory names are not case sensitive and will be automatically
 *      changed to all-CAPS
 * <li> Only files can have extensions
 * <li> Extensions are numberical in the range 0 to 125
 * <li> Extensions 100 to 125 are special purpose and not yet implemented or allowed
 * <li> Files can have the read-only attribute
 * <li> Directories can have the hidden attribute
 * <li> It is recommended to limit directory depth to 10 levels to accomodate
 *      legacy implementations
 * </ul>
 *
 * <H3> Usage </H3>
 * <DL>
 * <DD> <H4> Example </H4>
 * Read from a 1-Wire file on device 'owd':
 * <PRE> <CODE>
 *   // get an input stream to the 1-Wire file
 *   OWFileInputStream instream = new OWFileInputStream(owd, "DEMO.0");
 *
 *   // read some data
 *   byte[] data = new byte[2000];
 *   int len = instream.read(data);
 *
 *   // close the stream to release system resources
 *   instream.close();
 *
 * </CODE> </PRE>
 *
 * @author  DS
 * @version CLSID=5B7589D2-A1BB-4443-8EC7-7C801CA6CC6E -  0.01, 1 June 2001
 * @see     OWFile
 * @see     OWFileDescriptor
 * @see     OWFileOutputStream
 * @com.register ( clsid=5B7589D2-A1BB-4443-8EC7-7C801CA6CC6E, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OWFileInputStream
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.application.file.OWFileInputStream objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public OWFileInputStream()
   {
   }

   OWFileInputStream(com.dalsemi.onewire.application.file.OWFileInputStream o)
   {
      this.objectInstance = o;
   }
   OWFileInputStream(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.file.OWFileInputStream)o);
   }

   /**
    * Creates a <code>FileInputStream</code> by
    * opening a connection to an actual file,
    * the file named by the path name <code>name</code>
    * in the Filesystem.  A new <code>OWFileDescriptor</code>
    * object is created to represent this file
    * connection.
    * <p>
    * First, if there is a security
    * manager, its <code>checkRead</code> method
    * is called with the <code>name</code> argument
    * as its argument.
    * <p>
    * If the named file does not exist, is a directory rather than a regular
    * file, or for some other reason cannot be opened for reading then a
    * <code>FileNotFoundException</code> is thrown.
    *
    * @param      owd    OneWireContainer that this Filesystem resides on
    * @param      name   the system-dependent file name.
    * @exception  FileNotFoundException  if the file does not exist,
    *                   is a directory rather than a regular file,
    *                   or for some other reason cannot be opened for
    *                   reading.
    */
   public void createNewInstanceFromContainer(OneWireContainer owd, java.lang.String name)
      throws com.dalsemi.onewire.application.file.OWFileNotFoundException
   {      
      objectInstance = new com.dalsemi.onewire.application.file.OWFileInputStream(((com.dalsemi.onewire.container.OneWireContainer)owd.objectInstance), name);
   }

   /**
    * Creates a <code>FileInputStream</code> by
    * opening a connection to an actual file,
    * the file named by the path name <code>name</code>
    * in the Filesystem.  A new <code>OWFileDescriptor</code>
    * object is created to represent this file
    * connection.
    * <p>
    * First, if there is a security
    * manager, its <code>checkRead</code> method
    * is called with the <code>name</code> argument
    * as its argument.
    * <p>
    * If the named file does not exist, is a directory rather than a regular
    * file, or for some other reason cannot be opened for reading then a
    * <code>FileNotFoundException</code> is thrown.
    *
    * @param      owd    array of OneWireContainers that this Filesystem resides on
    * @param      name   the system-dependent file name.
    * @exception  FileNotFoundException  if the file does not exist,
    *                   is a directory rather than a regular file,
    *                   or for some other reason cannot be opened for
    *                   reading.
    */
   public void createNewInstanceFromContainers(OneWireContainerArray owd, java.lang.String name)
      throws com.dalsemi.onewire.application.file.OWFileNotFoundException
   {      
      objectInstance = new com.dalsemi.onewire.application.file.OWFileInputStream(owd.array, name);
   }

   /**
    * Creates a <code>OWFileInputStream</code> by
    * opening a connection to an actual file,
    * the file named by the <code>File</code>
    * object <code>file</code> in the Filesystem.
    * A new <code>OWFileDescriptor</code> object
    * is created to represent this file connection.
    * <p>
    * If the named file does not exist, is a directory rather than a regular
    * file, or for some other reason cannot be opened for reading then a
    * <code>FileNotFoundException</code> is thrown.
    *
    * @param      file   the file to be opened for reading.
    * @exception  FileNotFoundException  if the file does not exist,
    *                   is a directory rather than a regular file,
    *                   or for some other reason cannot be opened for
    *                   reading.
    * @see        OWFile#getPath()
    */
   public void createNewInstanceFromFile(OWFile a0)
      throws com.dalsemi.onewire.application.file.OWFileNotFoundException
   {      
      objectInstance = new com.dalsemi.onewire.application.file.OWFileInputStream(((com.dalsemi.onewire.application.file.OWFile)a0.objectInstance));
   }

   /**
    * Creates a <code>OWFileInputStream</code> by using the file descriptor
    * <code>fdObj</code>, which represents an existing connection to an
    * actual file in the Filesystem.
    * <p>
    * If <code>fdObj</code> is null then a <code>NullPointerException</code>
    * is thrown.
    *
    * @param      fdObj   the file descriptor to be opened for reading.
    */
   public void createNewInstance(OWFileDescriptor fdObj)
   {      
      objectInstance = new com.dalsemi.onewire.application.file.OWFileInputStream(((com.dalsemi.onewire.application.file.OWFileDescriptor)fdObj.objectInstance));
   }

   /**
    * Reads a byte of data from this input stream. This method blocks
    * if no input is yet available.
    *
    * @return     the next byte of data, or <code>-1</code> if the end of the
    *             file is reached.
    * @exception  IOException  if an I/O error occurs.
    */
   public int read()
      throws java.io.IOException
   {      
      return objectInstance.read();
   }

   /**
    * Reads up to <code>b.length</code> bytes of data from this input
    * stream into an array of bytes. This method blocks until some input
    * is available.
    *
    * @param      b   the buffer into which the data is read.
    * @return     the total number of bytes read into the buffer, or
    *             <code>-1</code> if there is no more data because the end of
    *             the file has been reached.
    * @exception  IOException  if an I/O error occurs.
    */
   public int read(ByteArray b )
      throws java.io.IOException
   {      
      return objectInstance.read(b .array);
   }

   /**
    * Reads up to <code>len</code> bytes of data from this input stream
    * into an array of bytes. This method blocks until some input is
    * available.
    *
    * @param      b     the buffer into which the data is read.
    * @param      off   the start offset of the data.
    * @param      len   the maximum number of bytes read.
    * @return     the total number of bytes read into the buffer, or
    *             <code>-1</code> if there is no more data because the end of
    *             the file has been reached.
    * @exception  IOException  if an I/O error occurs.
    */
   public int read(ByteArray b , int off, int len)
      throws java.io.IOException
   {      
      return objectInstance.read(b .array, off, len);
   }

   /**
    * Skips over and discards <code>n</code> bytes of data from the
    * input stream. The <code>skip</code> method may, for a variety of
    * reasons, end up skipping over some smaller number of bytes,
    * possibly <code>0</code>. The actual number of bytes skipped is returned.
    *
    * @param      n   the number of bytes to be skipped.
    * @return     the actual number of bytes skipped.
    * @exception  IOException  if an I/O error occurs.
    */
   public String skip(String n)
      throws java.io.IOException
   {      
      return ""+objectInstance.skip(Long.parseLong(n));
   }

   /**
    * Returns the number of bytes that can be read from this file input
    * stream without blocking.
    *
    * @return     the number of bytes that can be read from this file input
    *             stream without blocking.
    * @exception  IOException  if an I/O error occurs.
    */
   public int available()
      throws java.io.IOException
   {      
      return objectInstance.available();
   }

   /**
    * Closes this file input stream and releases any system resources
    * associated with the stream.
    *
    * @exception  IOException  if an I/O error occurs.
    */
   public void close()
      throws java.io.IOException
   {      
      objectInstance.close();
   }

   /**
    * Returns the <code>OWFileDescriptor</code>
    * object  that represents the connection to
    * the actual file in the Filesystem being
    * used by this <code>FileInputStream</code>.
    *
    * @return     the file descriptor object associated with this stream.
    * @exception  IOException  if an I/O error occurs.
    * @see        OWFileDescriptor
    */
   public final OWFileDescriptor getFD()
      throws java.io.IOException
   {      
      return new OWFileDescriptor(objectInstance.getFD());
   }

   /**
    * Ensures that the <code>close</code> method of this file input stream is
    * called when there are no more references to it.
    *
    * @exception  IOException  if an I/O error occurs.
    * @see        OWFileInputStream#close()
    */
   public void finalize()
      throws java.io.IOException
   {      
      objectInstance.finalize();
   }

   /**
    * Marks the current position in this input stream. A subsequent call to
    * the <code>reset</code> method repositions this stream at the last marked
    * position so that subsequent reads re-read the same bytes.
    *
    * <p> The <code>readlimit</code> arguments tells this input stream to
    * allow that many bytes to be read before the mark position gets
    * invalidated.
    *
    * <p> The general contract of <code>mark</code> is that, if the method
    * <code>markSupported</code> returns <code>true</code>, the stream somehow
    * remembers all the bytes read after the call to <code>mark</code> and
    * stands ready to supply those same bytes again if and whenever the method
    * <code>reset</code> is called.  However, the stream is not required to
    * remember any data at all if more than <code>readlimit</code> bytes are
    * read from the stream before <code>reset</code> is called.
    *
    * <p> The <code>mark</code> method of <code>InputStream</code> does
    * nothing.
    *
    * @param   readlimit   the maximum limit of bytes that can be read before
    *                      the mark position becomes invalid.
    * @see     java.io.InputStream#reset()
    */
   public void mark(int readlimit)
   {      
      objectInstance.mark(readlimit);
   }

   /**
    * Repositions this stream to the position at the time the
    * <code>mark</code> method was last called on this input stream.
    *
    * <p> The general contract of <code>reset</code> is:
    *
    * <p><ul>
    *
    * <li> If the method <code>markSupported</code> returns
    * <code>true</code>, then:
    *
    *     <ul><li> If the method <code>mark</code> has not been called since
    *     the stream was created, or the number of bytes read from the stream
    *     since <code>mark</code> was last called is larger than the argument
    *     to <code>mark</code> at that last call, then an
    *     <code>IOException</code> might be thrown.
    *
    *     <li> If such an <code>IOException</code> is not thrown, then the
    *     stream is reset to a state such that all the bytes read since the
    *     most recent call to <code>mark</code> (or since the start of the
    *     file, if <code>mark</code> has not been called) will be resupplied
    *     to subsequent callers of the <code>read</code> method, followed by
    *     any bytes that otherwise would have been the next input data as of
    *     the time of the call to <code>reset</code>. </ul>
    *
    * <li> If the method <code>markSupported</code> returns
    * <code>false</code>, then:
    *
    *     <ul><li> The call to <code>reset</code> may throw an
    *     <code>IOException</code>.
    *
    *     <li> If an <code>IOException</code> is not thrown, then the stream
    *     is reset to a fixed state that depends on the particular type of the
    *     input stream and how it was created. The bytes that will be supplied
    *     to subsequent callers of the <code>read</code> method depend on the
    *     particular type of the input stream. </ul></ul>
    *
    * <p> The method <code>reset</code> for class <code>InputStream</code>
    * does nothing and always throws an <code>IOException</code>.
    *
    * @exception  IOException  if this stream has not been marked or if the
    *               mark has been invalidated.
    * @see     java.io.InputStream#mark(int)
    * @see     java.io.IOException
    */
   public void reset()
      throws java.io.IOException
   {      
      objectInstance.reset();
   }

   /**
    * Tests if this input stream supports the <code>mark</code> and
    * <code>reset</code> methods. The <code>markSupported</code> method of
    * <code>InputStream</code> returns <code>false</code>.
    *
    * @return  <code>true</code> if this true type supports the mark and reset
    *          method; <code>false</code> otherwise.
    * @see     java.io.InputStream#mark(int)
    * @see     java.io.InputStream#reset()
    */
   public boolean markSupported()
   {      
      return objectInstance.markSupported();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OWFileInputStream setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.file.OWFileInputStream)o;
      return this;
   }
}
