// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for temperature iButton which measures temperatures
 * from -55&#176C to +100&#176C, DS1920 or DS18S20.  This container encapsulates the
 * functionality of the iButton family type <B>10</B> (hex)</P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Measures temperatures from -55&#176C to +100&#176C in typically 0.2 seconds
 *   <LI> Zero standby power
 *   <LI> 0.5&#176C resolution, digital temperature reading in twos complement
 *   <LI> Increased resolution through interpolation in internal counters
 *   <LI> 8-bit device-generated CRC for data integrity
 *   <LI> Special command set allows user to skip ROM section and do temperature
 *        measurements simultaneously for all devices on the bus
 *   <LI> 2 bytes of EEPROM to be used either as alarm triggers or user memory
 *   <LI> Alarm search directly indicates which device senses alarming temperatures
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage example in
 * {@link TemperatureContainer TemperatureContainer}
 * for temperature specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1920.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1920.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS18S20.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS18S20.pdf</A>
 * </DL>
 *
 * @see TemperatureContainer
 *
 * @version CLSID=D502EDCE-2FE2-4059-9F70-D1FC692D7AD6 -     1.00, 1 Sep 2000
 * @author     DS,JK
 * Converted to use TemperatureContainer interface 9-1-2000 KLA
 * @com.register ( clsid=D502EDCE-2FE2-4059-9F70-D1FC692D7AD6, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer10
   extends OneWireContainer
   implements com.ms.com.IUnknown, TemperatureContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer10 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer10()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer10());
   }

   OneWireContainer10(com.dalsemi.onewire.container.OneWireContainer10 o)
   {
      super(o);
   }
   OneWireContainer10(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer10)o);
   }

   public static final double RESOLUTION_NORMAL
          = com.dalsemi.onewire.container.OneWireContainer10.RESOLUTION_NORMAL;

   public static final double RESOLUTION_MAXIMUM
          = com.dalsemi.onewire.container.OneWireContainer10.RESOLUTION_MAXIMUM;

   /**
    * Checks to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>OneWireContainer10</code>
    *         has high/low trip alarms
    *
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Checks to see if this device has selectable temperature resolution.
    *
    * @return <code>true</code> if this <code>OneWireContainer10</code>
    *         has selectable temperature resolution
    *
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Gets an array of available temperature resolutions in Celsius.
    *
    * @return byte array of available temperature resolutions in Celsius for
    *         this <code>OneWireContainer10</code>. The minimum resolution is
    *         returned as the first element and maximum resolution as the last
    *         element.
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #setTemperatureResolution
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getTemperatureResolutions());
   }

   /**
    * Gets the temperature alarm resolution in Celsius.
    *
    * @return temperature alarm resolution in Celsius for this
    *         <code>OneWireContainer10</code>
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    *
    */
   public double getTemperatureAlarmResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Gets the maximum temperature in Celsius.
    *
    * @return maximum temperature in Celsius for this
    *         <code>OneWireContainer10</code>
    *
    * @see    #getMinTemperature
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getMaxTemperature();
   }

   /**
    * Gets the minimum temperature in Celsius.
    *
    * @return minimum temperature in Celsius for this
    *         <code>OneWireContainer10</code>
    *
    * @see    #getMaxTemperature
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getMinTemperature();
   }

   /**
    * Performs a temperature conversion on <code>state</code> information.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer10</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #getTemperature
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * Gets the temperature value in Celsius from the <code>state</code>
    * data retrieved from the <code>readDevice()</code> method.
    *
    * @param  state byte array with device state information for this
    *         <code>OneWireContainer10</code>
    *
    * @return temperature in Celsius from the last
    *                     <code>doTemperatureConvert()</code>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer10</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    *
    * @see    #doTemperatureConvert
    */
   public double getTemperature(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getTemperature(state.array);
   }

   /**
    * Gets the specified temperature alarm value in Celsius from the
    * <code>state</code> data retrieved from the  <code>readDevice()</code>
    * method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return temperature alarm trip values in Celsius for this
    *         <code>OneWireContainer10</code>
    *
    * @see    #hasTemperatureAlarms
    * @see    #setTemperatureAlarm
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * Gets the current temperature resolution in Celsius from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature resolution in Celsius for this
    *         <code>OneWireContainer10</code>
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * Sets the temperature alarm value in Celsius in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in Celsius
    * @param  state      byte array with device state information
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current temperature resolution in Celsius in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution temperature resolution in Celsius. Valid values are
    *                    <code>RESOLUTION_NORMAL</code> and
    *                    <code>RESOLUTION_MAXIMUM</code>.
    * @param  state      byte array with device state information
    *
    * @see    #RESOLUTION_NORMAL
    * @see    #RESOLUTION_MAXIMUM
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Retrieves this <code>OneWireContainer10</code> state information.
    * The state information is returned as a byte array.  Pass this byte
    * array to the '<code>get</code>' and '<code>set</code>' methods.
    * If the device state needs to be changed, then call the
    * <code>writeDevice()</code> to finalize the changes.
    *
    * @return <code>OneWireContainer10</code> state information.
    * Device state looks like this:
    * <pre>
    *   0 : temperature LSB
    *   1 : temperature MSB
    *   2 : trip high
    *   3 : trip low
    *   4 : reserved (put the resolution here, 0 for normal, 1 for max)
    *   5 : reserved
    *   6 : count remain
    *   7 : count per degree Celsius
    *   8 : an 8 bit CRC over the previous 8 bytes of data
    * </pre>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer10</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #writeDevice
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).readDevice());
   }

   /**
    * Writes to this <code>OneWireContainer10</code> <code>state</code>
    * information that have been changed by '<code>set</code>' methods.
    * Only the state registers that changed are updated.  This is done
    * by referencing a field information appended to the state data.
    *
    * @param  state      byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer10</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #readDevice
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer10)objectInstance).writeDevice(state.array);
   }

   /**
    * Converts a temperature reading from Celsius to Fahrenheit.
    *
    * @param   celsiusTemperature temperature value in Celsius
    *
    * @return  the Fahrenheit conversion of the supplied temperature
    *
    * @deprecated Replace with call to toFahrenheit()
    *
    * @see Convert#toFahrenheit(double)
    */
   public double convertToFahrenheit(double a0)
   {      
      return com.dalsemi.onewire.container.OneWireContainer10.convertToFahrenheit(a0);
   }

   /**
    * Converts a temperature reading from Fahrenheit to Celsius.
    *
    * @param  fahrenheitTemperature temperature value in Fahrenheit
    *
    * @return  the Celsius conversion of the supplied temperature
    *
    * @deprecated Replace with call to toCelsius()
    *
    * @see Convert#toCelsius(double)
    */
   public double convertToCelsius(double a0)
   {      
      return com.dalsemi.onewire.container.OneWireContainer10.convertToCelsius(a0);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer10)o;
      return this;
   }
}
