// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 512 byte memory iButton with write cycle counters, DS1963L.  This container
 * encapsulates the functionality of the iButton family 
 * type <B>1A</B> (hex)</P>
 *
 * <P> This iButton is primarily used as a read/write portable memory device that
 * provides tamper detection when utilizing the write counters. </P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> 4096 bits (512 bytes) of read/write nonvolatile memory
 *   <LI> 256-bit (32-byte) scratchpad ensures integrity of data
 *        transfer
 *   <LI> Memory partitioned into 256-bit (32-byte) pages for
 *        packetizing data
 *   <LI> Data integrity assured with strict read/write
 *        protocols
 *   <LI> Overdrive mode boosts communication to
 *        142 kbits per second
 *   <LI> Four 32-bit read-only non rolling-over page
 *        write cycle counters
 *   <LI> 32 factory-preset tamper-detect bits to
 *        indicate physical intrusion
 *   <LI> On-chip 16-bit CRC generator for
 *        safeguarding data transfers
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C
 *   <LI> Over 10 years of data retention
 * </UL>
 * 
 * <H3> Memory </H3> 
 *  
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 * 
 * The following is a list of the MemoryBank instances that are returned: 
 *
 * <UL>
 *   <LI> <B> Scratchpad Ex </B> 
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                   {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes 
 *         <LI> <I> Extra information for each page</I>  Target address, offset, length 3
 *      </UL> 
 *   <LI> <B> Main Memory </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 384 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 12 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC 
 *      </UL> 
 *   <LI> <B> Memory with write cycle counter </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 128 starting at physical address 384
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 4 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC 
 *         <LI> <I> Extra information for each page</I>  Write cycle counter, length 8
 *      </UL> 
 * </UL>
 * 
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> See the usage example in 
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in 
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1963L.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1963L.pdf</A>
 * </DL>
 * 
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see OneWireContainer18
 * 
 * @version CLSID=26DA1D93-5997-4BAB-9777-FC101D74CE78 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=26DA1D93-5997-4BAB-9777-FC101D74CE78, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer1A
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer1A objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer1A()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer1A());
   }

   OneWireContainer1A(com.dalsemi.onewire.container.OneWireContainer1A o)
   {
      super(o);
   }
   OneWireContainer1A(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer1A)o);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer1A)o;
      return this;
   }
}
