// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 512 byte memory with external counters, DS2423.  This container
 * encapsulates the functionality of the 1-Wire family 
 * type <B>1D</B> (hex)</P>
 *
 * <P> This 1-Wire device is primarily used as a counter with memory. </P>
 *
 * <P> Each counter is assosciated with a memory page.  The counters for pages 
 * 12 and 13 are incremented with a write to the memory on that page.  The counters
 * for pages 14 and 15 are externally triggered. See the method
 * {@link #readCounter(int) readCounter} to read a counter directly.  Note that the
 * the counters may also be read with the <CODE> PagedMemoryBank </CODE> interface 
 * as 'extra' information on a page read. </P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> 4096 bits (512 bytes) of read/write nonvolatile memory
 *   <LI> 256-bit (32-byte) scratchpad ensures integrity of data
 *        transfer
 *   <LI> Memory partitioned into 256-bit (32-byte) pages for
 *        packetizing data
 *   <LI> Data integrity assured with strict read/write
 *        protocols
 *   <LI> Overdrive mode boosts communication to
 *        142 kbits per second
 *   <LI> Four 32-bit read-only non rolling-over page
 *        write cycle counters
 *   <LI> Active-low external trigger inputs for two of
 *        the counters with on-chip debouncing
 *        compatible with reed and Wiegand switches
 *   <LI> 32 factory-preset tamper-detect bits to
 *        indicate physical intrusion
 *   <LI> On-chip 16-bit CRC generator for
 *        safeguarding data transfers
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C
 *   <LI> Over 10 years of data retention
 * </UL>
 * 
 * <H3> Memory </H3> 
 *  
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 * 
 * The following is a list of the MemoryBank instances that are returned: 
 *
 * <UL>
 *   <LI> <B> Scratchpad Ex </B> 
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                   {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes 
 *         <LI> <I> Extra information for each page</I>  Target address, offset, length 3
 *      </UL> 
 *   <LI> <B> Main Memory </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 384 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 12 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC 
 *      </UL> 
 *   <LI> <B> Memory with write cycle counter </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 384
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 2 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC 
 *         <LI> <I> Extra information for each page</I>  Write cycle counter, length 8
 *      </UL> 
 *   <LI> <B> Memory with externally triggered counter </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 448
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 2 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC 
 *         <LI> <I> Extra information for each page</I>  Externally triggered counter, length 8
 *      </UL> 
 * </UL>
 * 
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> <H4> Example</H4> 
 * Read the two external counters of this containers instance 'owd': 
 * <PRE> <CODE>
 *  System.out.print("Counter on page 14: " + owd.readCounter(14));
 *  System.out.print("Counter on page 15: " + owd.readCounter(15));
 * </CODE> </PRE>
 * <DD> See the usage example in 
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in 
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2422-DS2423.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2422-DS2423.pdf</A>
 * </DL>
 * 
 * @see MemoryBank
 * @see PagedMemoryBank
 * 
 * @version CLSID=8915D91D-D208-41E1-BE60-C273B366D132 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=8915D91D-D208-41E1-BE60-C273B366D132, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer1D
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer1D objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer1D()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer1D());
   }

   OneWireContainer1D(com.dalsemi.onewire.container.OneWireContainer1D o)
   {
      super(o);
   }
   OneWireContainer1D(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer1D)o);
   }

   /**
    * Read the counter value associated with a page on this 
    * 1-Wire Device.
    *
    * @param  counterPage    page number of the counter to read
    *
    * @return  4 byte value counter stored in a long integer
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no 1-Wire device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter
    */
   public String readCounter(int counterPage)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer1D)objectInstance).readCounter(counterPage);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer1D)o;
      return this;
   }
}
