// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 512 byte EEPROM memory iButton, DS1973 and 1-Wire Chip, DS2433. 
 * This container encapsulates the functionality of the 1-Wire family 
 * type <B>23</B> (hex)</P>
 *
 * <P> The iButton package for this device is primarily used as a read/write portable memory device.  
 * The 1-Wire Chip version is used for small non-volatile storage. </P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> 4096 bits (512 bytes) Electrically Erasable Programmable Read Only Memory
 *        (EEPROM)
 *   <LI> 256-bit (32-byte) scratchpad ensures integrity of data
 *        transfer
 *   <LI> Memory partitioned into 256-bit (32-byte) pages for
 *        packetizing data
 *   <LI> Overdrive mode boosts communication to
 *        142 kbits per second
 *   <LI> Reduces control, address, data and power to
 *        a single data pin
 *   <LI> Reads and writes over a wide voltage range
 *        of 2.8V to 6.0V from -40&#176C to +85&#176C environments
 * </UL>
 * 
 * <H3> Alternate Names </H3>
 * <UL>
 *   <LI> DS2433 
 * </UL>
 *
 * <H3> Memory </H3> 
 *  
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 * 
 * The following is a list of the MemoryBank instances that are returned: 
 *
 * <UL>
 *   <LI> <B> Scratchpad </B> 
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                   {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes 
 *         <LI> <I> Extra information for each page</I>  Target address, offset, length 3
 *      </UL> 
 *   <LI> <B> Main Memory </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 512 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 16 pages of length 32 bytes giving 29 bytes Packet data payload
 *      </UL> 
 * </UL>
 * 
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> See the usage example in 
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in 
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheets </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1973.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1973.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2433.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2433.pdf</A>
 * </DL>
 * 
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see OneWireContainer14
 * 
 * @version CLSID=732F307F-8955-4A19-817D-AA54F940A2B1 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=732F307F-8955-4A19-817D-AA54F940A2B1, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer23
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer23 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer23()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer23());
   }

   OneWireContainer23(com.dalsemi.onewire.container.OneWireContainer23 o)
   {
      super(o);
   }
   OneWireContainer23(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer23)o);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer23)o;
      return this;
   }
}
