// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>1-Wire&#174 container that encapsulates the functionality of the 1-Wire
 * family type <b>2C</B> (hex), Dallas Semiconductor part number: <B>DS2890,
 * 1-Wire Digital Potentiometer</B>.</P>
 *
 *
 * <H3>Features</H3>
 * <UL>
 *   <LI>Single element 256-position linear taper potentiometer
 *   <LI>Supports potentiometer terminal working voltages up to 11V
 *   <LI>Potentiometer terminal voltage independant of supply voltage
 *   <LI>100k Ohm resistor element value
 *   <LI>Operating temperature range from -40&#176C to
 *       +85&#176C
 *   <LI>2.8V - 6.0V operating voltage range
 * </UL>
 *
 * <H3>Data sheet</H3>
 *
 *   <A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2890.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2890.pdf</A>
 *
 * @version CLSID=28456E22-B339-4972-9173-C88235BD65A9 -     0.00, 28 Aug 2000
 * @author     KLA
 * @com.register ( clsid=28456E22-B339-4972-9173-C88235BD65A9, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer2C
   extends OneWireContainer
   implements com.ms.com.IUnknown, PotentiometerContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer2C objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer2C()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer2C());
   }

   OneWireContainer2C(com.dalsemi.onewire.container.OneWireContainer2C o)
   {
      super(o);
   }
   OneWireContainer2C(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer2C)o);
   }

   /**
    * Queries to see if this Potentiometer One Wire Device
    * has linear potentiometer element(s) or logarithmic
    * potentiometer element(s).
    *
    * @param state state buffer of the Potentiometer One Wire Device
    *              (returned by <CODE>readDevice()</CODE>)
    * @return <CODE>true</CODE> if this device has linear potentiometer
    *         element(s); <CODE>false</CODE> if this device has logarithmic
    *         potentiometer element(s)
    */
   public boolean isLinear(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).isLinear(state.array);
   }

   /**
    * Queries to see if this 1-Wire Potentiometer device's
    * wiper settings are volatile or non-volatile.
    *
    * @param state state buffer of the 1-Wire Potentiometer device
    *              (returned by <CODE>readDevice()</CODE>)
    * @return <CODE>true</CODE> if the wiper settings are volatile;
    *         <CODE>false</CODE> if the wiper settings are non-volatile
    */
   public boolean wiperSettingsAreVolatile(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).wiperSettingsAreVolatile(state.array);
   }

   /**
    * Queries to see how many potentiometers this
    * Potentiometer One Wire Device has.
    *
    * @param state state buffer of this 1-Wire Potentiometer device
    *             (returned by <CODE>readDevice()</CODE>)
    * @return the number of potentiometers on this device
    */
   public int numberOfPotentiometers(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).numberOfPotentiometers(state.array);
   }

   /**
    * Queries to find the number of wiper settings
    * that any wiper on this Potentiometer One Wire
    * Device can have.
    *
    * @param state state buffer of this 1-Wire Potentiometer device
    *             (returned by <CODE>readDevice()</CODE>)
    * @return number of wiper positions available
    */
   public int numberOfWiperSettings(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).numberOfWiperSettings(state.array);
   }

   /**
    * Queries to find the resistance value of the potentiometer.
    *
    * @param state state buffer of this 1-Wire Potentiometer device
    *             (returned by <CODE>readDevice()</CODE>)
    * @return the resistance value in k-Ohms
    */
   public int potentiometerResistance(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).potentiometerResistance(state.array);
   }

   /**
    * Gets the currently selected wiper number.  All wiper actions
    * affect this wiper.  The number of wipers is the same as
    * <CODE>numberOfPotentiometers()</CODE>.
    *
    * @param state state buffer of this 1-Wire Potentiometer device
    *              (returned by <CODE>readDevice()</CODE>)
    * @return the current wiper number
    */
   public int getCurrentWiperNumber(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).getCurrentWiperNumber(state.array);
   }

   /**
    * Sets the currently selected wiper number.  All wiper actions
    * affect this wiper.  The number of wipers is the same as
    * <CODE>numberOfPotentiometers()</CODE>.
    *
    * @param wiper_number wiper number to select for communication.
    * Valid choices are 0 to 3
    * @param state state buffer of this 1-Wire Potentiometer device
    *             (returned by <CODE>readDevice()</CODE>)
    */
   public void setCurrentWiperNumber(int wiper_number, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).setCurrentWiperNumber(wiper_number, state.array);
   }

   /**
    * Determines if this device's charge pump is enabled.
    *
    * @param state state buffer of this Potentiometer One Wire Device
    *             (returned by <CODE>readDevice()</CODE>)
    * @return <CODE>true</CODE> if it is enabled; <CODE>false</CODE> if not
    */
   public boolean isChargePumpOn(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).isChargePumpOn(state.array);
   }

   /**
    * Sets this device's charge pump.  This decreases the wiper's resistance,
    * but increases the power consumption by the part.  Vdd must be
    * connected to use the charge pump (see the DS2890 datasheet for
    * more information at <A HREF="http://www.dalsemi.com">www.dalsemi.com</A>)
    *
    * @param charge_pump_on <CODE>true</CODE> if you want to enable the charge pump
    * @param state state buffer of this Potentiometer One Wire Device
    *             (returned by <CODE>readDevice()</CODE>)
    * @return <CODE>true</CODE> if the operation was successful;
    *         <CODE>false</CODE> if there was an error
    */
   public void setChargePump(boolean charge_pump_on, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).setChargePump(charge_pump_on, state.array);
   }

   /**
    * Gets the current wiper position of this device.  The wiper position
    * is between 0 and 255, and describes the voltage output.  The
    * output lies between RH and RL.
    *
    * @return the wiper position between 0 and 255
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public int getWiperPosition()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).getWiperPosition();
   }

   /**
    * Sets the wiper position for the potentiometer.
    *
    * @param position the position to set the wiper.  This value will be cast
    *  to a byte, only the 8 least significant bits matter.
    * @return <CODE>true</CODE> if the operation was successful;
    *         <CODE>false</CODE> otherwise
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public boolean setWiperPosition(int position)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).setWiperPosition(position);
   }

   /**
    * Increments the wiper position.
    *
    * @param reselect increment/decrement can be called without resetting
    *                 the part if the last call was an increment/decrement.
    *                 <CODE>true</CODE> if you want to select the part
    *                 (you must call with <CODE>true</CODE> after any other
    *                 one-wire method)
    * @return the new position of the wiper (0-255)
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public int increment(boolean reselect)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).increment(reselect);
   }

   /**
    * Decrements the wiper position.
    *
    * @param reselect increment/decrement can be called without resetting
    *                 the part if the last call was an increment/decrement.
    *                 <CODE>true</CODE> if you want to select the part (you
    *                 must call with <CODE>true</CODE> after any other one-wire
    *                 method)
    * @return the new position of the wiper (0-255)
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public int decrement(boolean reselect)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).decrement(reselect);
   }

   /**
    * Increments the wiper position.
    *
    * @param reselect increment/decrement can be called without resetting
    *                 the part if the last call was an increment/decrement.
    *                 <CODE>true</CODE> if you want to select the part
    *                 (you must call with <CODE>true</CODE> after any other
    *                 one-wire method)
    * @return the new position of the wiper (0-255)
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public int increment()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).increment();
   }

   /**
    * Decrements the wiper position.
    *
    * @param reselect increment/decrement can be called without resetting
    *                 the part if the last call was an increment/decrement.
    *                 <CODE>true</CODE> if you want to select the part (you
    *                 must call with <CODE>true</CODE> after any other one-wire
    *                 method)
    * @return the new position of the wiper (0-255)
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public int decrement()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).decrement();
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the static query
    * and set methods.  If the device state needs to be changed then call
    * the <CODE>writeDevice</CODE> to finalize the one or more change.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException Data was not read correctly
    * @throws OneWireException Could not find device
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that have been changed
    * by the 'set' methods.  It knows which registers have
    * changed by looking at the bitmap fields appended to the state
    * data.
    *
    * @param  state byte array of clock register page contents
    *
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find device
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer2C)objectInstance).writeDevice(state.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer2C)o;
      return this;
   }
}
