// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>1-Wire&#174 container for the '1K-Bit protected 1-Wire EEPROM 
 * family type <B>2D</B> (hex), Dallas Semiconductor part number:
 * <B>DS2431</B>.
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> 1024 bits of 5V EEPROM memory partitioned into four pages of 256 bits
 *   <LI> unique, fatory-lasered and tested 64-bit registration number (8-bit
 *        family code + 48-bit serial number + 8-bit CRC tester) assures
 *        absolute traceablity because no two parts are alike.
 *   <LI> Built-in multidrop controller ensures compatibility with other 1-Wire
 *        net products.
 *   <LI> Reduces control, address, data and power to a single data pin.
 *   <LI> Directly connects to a single port pin of a microprocessor and
 *        communicates at up to 16.3k bits per second.
 *   <LI> Overdrive mode boosts communication speed to 142k bits per second.
 *   <LI> 8-bit family code specifies DS2431 communication requirements to reader.
 *   <LI> Presence detector acknowledges when reader first applies voltage.
 *   <LI> Low cost 6-lead TSOC surface mount package
 *   <LI> Reads and writes over a wide voltage range of 2.8V to 5.25V from -40C
 *        to +85C.
 * </UL>
 *
 * <P> The memory can also be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * <DL>
 * <DD> </A>
 * </DL>
 *
 * @version CLSID=D07EA07D-B005-46B7-B82C-E867B66D5E8C -  	0.00, 10 March 2004
 * @author DS
 * @com.register ( clsid=D07EA07D-B005-46B7-B82C-E867B66D5E8C, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer2D
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer2D objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer2D()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer2D());
   }

   OneWireContainer2D(com.dalsemi.onewire.container.OneWireContainer2D o)
   {
      super(o);
   }
   OneWireContainer2D(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer2D)o);
   }

   public static final byte WRITEONCE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer2D.WRITEONCE_FLAG;

   /**
    * Query to see if current memory bank is write write once such
    * as with EPROM technology.
    *
    * @return  'true' if current memory bank can only be written once
    */
   public boolean isPageWriteOnce(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer2D)objectInstance).isPageWriteOnce(page);
   }

   /**
    * Lock the specifed page in the current memory bank.  Not supported
    * by all devices.  See the method 'canLockPage()'.
    *
    * @param  page   number of page to lock
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void setPageWriteOnce(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer2D)objectInstance).setPageWriteOnce(page);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer2D)o;
      return this;
   }
}
