// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Class representing DS1963S (or DS2421), family-code 0x18, SHA iButtons as a user
 * token in SHA Transactions.</P>
 *
 * @see SHATransaction
 * @see SHAiButtonCopr
 * @see SHAiButtonUser33
 *
 * @version CLSID=DAAE37E9-CA16-422E-946D-22B1C0D2CFA4 -  1.00
 * @author  SKH
 * @com.register ( clsid=DAAE37E9-CA16-422E-946D-22B1C0D2CFA4, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHAiButtonUser18
   extends SHAiButtonUser
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: SHAiButtonUser
   //com.dalsemi.onewire.application.sha.SHAiButtonUser18 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHAiButtonUser18()
   {
   }

   SHAiButtonUser18(com.dalsemi.onewire.application.sha.SHAiButtonUser18 o)
   {
      super(o);
   }
   SHAiButtonUser18(java.lang.Object o)
   {
      super((com.dalsemi.onewire.application.sha.SHAiButtonUser18)o);
   }

   /**
    * <P>Initialize a DS1963S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser18(SHAiButtonCopr,OneWireContainer18)
    * @see #SHAiButtonUser18(SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr, OneWireContainer18 owc, boolean formatDevice, ByteArray authSecret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser18(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), ((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance), formatDevice, authSecret.array);
   }

   /**
    * <P>Initialize a DS1963S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * @param coprBindData The Coprocessor Bind Data, used to create a unique
    *        secret for this user token.
    * @param coprBindCode The Coprocessor Bind Code without the user-specific
    *        information, used to create a unique secret for this user token.
    * @param fileName The file name for the account info.
    * @param fileNameExt The file extenstion for the account info
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser18(SHAiButtonCopr,OneWireContainer18)
    * @see #SHAiButtonUser18(SHAiButtonCopr)
    */
   public void createNewInstanceFromCoprocessor(ByteArray coprBindData, ByteArray coprBindCode, ByteArray fileName, int fileNameExt, OneWireContainer18 owc, boolean formatDevice, ByteArray authSecret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser18(coprBindData.array, coprBindCode.array, fileName.array, fileNameExt, ((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance), formatDevice, authSecret.array);
   }

   /**
    * <P>Initialize a DS1963S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser18(SHAiButtonCopr,OneWireContainer18)
    * @see #SHAiButtonUser18(SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr, OneWireContainer18 owc)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser18(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), ((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance));
   }

   /**
    * <P>Initialize a DS1963S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * @param coprBindData The Coprocessor Bind Data, used to create a unique
    *        secret for this user token.
    * @param coprBindCode The Coprocessor Bind Code without the user-specific
    *        information, used to create a unique secret for this user token.
    * @param fileName The file name for the account info.
    * @param fileNameExt The file extenstion for the account info
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser18(SHAiButtonCopr,OneWireContainer18)
    * @see #SHAiButtonUser18(SHAiButtonCopr)
    */
   public void createNewInstanceFromCoprocessor(ByteArray coprBindData, ByteArray coprBindCode, int fileName, OneWireContainer18 fileNameExt)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser18(coprBindData.array, coprBindCode.array, fileName, ((com.dalsemi.onewire.container.OneWireContainer18)fileNameExt.objectInstance));
   }

   /**
    * <P>Initialize a DS1963S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser18(SHAiButtonCopr,OneWireContainer18)
    * @see #SHAiButtonUser18(SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser18(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance));
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another DS1963S
    * container.  This function only copies the reference to the
    * OneWireContainer, copes the reference to it's 1-Wire address, and
    * then asserts that the iButton contains a valid acccount info file
    * associated with the system.</P>
    *
    * @param owc The <code>OneWireContainer18</code> this object will refer to.
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButton18FromCoprocessor(OneWireContainer18 owc)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).setiButton18(((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance));
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another 1963S.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButtonUserFromCoprocessor(DSPortAdapter adapter, ByteArray address)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).setiButtonUser(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), address.array);
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another 1963S.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButtonUserFromCoprocessor(ByteArray adapter)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).setiButtonUser(adapter.array);
   }

   /**
    * <P>Returns the value of the write cycle counter for the
    * page where the account data is stored.  If the write
    * cycle counter has ever been retrieved, this returns the
    * cached value.  Otherwise, this method reads the value
    * from the part.</P>
    *
    * @return the value of the write cycle counter for the
    *         account data page.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized int getWriteCycleCounter()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).getWriteCycleCounter();
   }

   /**
    * Returns <code>true</code> if this buttons account data is stored
    * on a page that has a write cycle counter.
    *
    * @return <code>true</code> if account page has write cycle counter.
    */
   public synchronized boolean hasWriteCycleCounter()
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).hasWriteCycleCounter();
   }

   /**
    * <P>Writes the account data to the SHAiButton.  First, this function
    * asserts that the account page number is known.  The account data is
    * copied from dataBuffer starting at the offset.  If there are less
    * than 32 bytes available to copy, this function only copies the bytes
    * that are available.</P>
    *
    * @param dataBuffer the buffer to copy the account data from
    * @param offset the index into the buffer where copying should begin
    * @return whether or not the data write succeeded
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean writeAccountDataFromCoprocessor(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).writeAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a standard READ
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  The 32 byte account
    * data page is copied into dataBuffer starting at the given offset.</P>
    *
    * @param dataBuffer the buffer to copy the account data into
    * @param offset the index into the buffer where copying should begin
    *
    * @return whether or not the read was successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean readAccountDataFromCoprocessor(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).readAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a READ_AUTHENTICATE
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  Then it copies the
    * 3 byte challenge to the scratchpad before sending the command for
    * READ_AUTHENTICATE.  The 32 byte account data page is copied into
    * dataBuffer starting at dataStart.</P>
    *
    * <P>In addition to the account data, this function also returns a
    * calculated MAC.  The MAC requires 20 bytes after the start index.
    * The return value is the write cycle counter value for the account
    * data page<p>
    *
    * @param chlg the buffer containing a 3-byte random challenge.
    * @param chlgStart the index into the buffer where the 3 byte
    *        challenge begins.
    * @param dataBuffer the buffer to copy the account data into
    * @param dataStart the index into the buffer where copying should begin
    * @param mac the buffer to copy the resulting Message Authentication Code
    * @param macStart the index into the mac buffer to start copying
    *
    * @return the value of the write cycle counter for the page
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized int readAccountDataFromCoprocessor(ByteArray chlg, int chlgStart, ByteArray dataBuffer, int dataStart, ByteArray mac, int macStart)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser18)objectInstance).readAccountData(chlg.array, chlgStart, dataBuffer.array, dataStart, mac.array, macStart);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHAiButtonUser setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHAiButtonUser18)o;
      return this;
   }
}
